sniffio: Sniff out which async library your code is running under
=================================================================

Description
-----------

Sniff out which async library your code is running under

License
-------

MIT OR Apache-2.0

Upstream Contact
----------------

https://pypi.org/project/sniffio/

